All pastes #88862 Raw Edit

Mine

public text v1 · immutable
#88862 ·published 2006-07-15 12:03 UTC
rendered paste body
nvidia-installer log file '/var/log/nvidia-installer.log'
creation time: Sat Jul 15 14:00:48 2006

option status:
  license pre-accepted    : false
  update                  : false
  force update            : false
  expert                  : false
  uninstall               : false
  driver info             : false
  no precompiled interface: false
  no ncurses color        : false
  query latest driver ver : false
  OpenGL header files     : true
  no questions            : false
  silent                  : false
  no backup               : false
  kernel module only      : false
  sanity                  : false
  add this kernel         : false
  no runlevel check       : false
  no network              : false
  no ABI note             : false
  no RPMs                 : false
  force tls               : (not specified)
  force compat32 tls      : (not specified)
  X install prefix        : /usr/X11R6
  OpenGL install prefix   : /usr
  compat32 install prefix : (not specified)
  installer install prefix: /usr
  utility install prefix  : /usr
  kernel name             : (not specified)
  kernel include path     : (not specified)
  kernel source path      : (not specified)
  kernel output path      : (not specified)
  kernel install path     : (not specified)
  proc mount point        : /proc
  ui                      : (not specified)
  tmpdir                  : /tmp
  ftp mirror              : ftp://download.nvidia.com
  RPM file list           : (not specified)

Using: nvidia-installer ncurses user interface
-> License accepted.
-> There appears to already be a driver installed on your system (version: 1.0-
   8762).  As part of installing this driver (version: 1.0-8762), the existing 
   driver will be uninstalled.  Are you sure you want to continue? ('no' will a
   bort installation) (Answer: Yes)
-> No precompiled kernel interface was found to match your kernel; would you li
   ke the installer to attempt to download a kernel interface for your kernel f
   rom the NVIDIA ftp site (ftp://download.nvidia.com)? (Answer: Yes)
-> No matching precompiled kernel interface was found on the NVIDIA ftp site;
   this means that the installer will need to compile a kernel interface for
   your kernel.
-> Performing CC test with CC="cc".
-> Kernel source path: '/lib/modules/2.6.15-26-386/build'
-> Kernel output path: '/lib/modules/2.6.15-26-386/build'
-> Performing rivafb check.
-> Performing nvidiafb check.
-> Cleaning kernel module build directory.
   executing: 'cd ./usr/src/nv; make clean'...
   rm -f -f nv.o nv-vm.o os-agp.o os-interface.o os-registry.o nv-i2c.o nv.o nv
   -vm.o os-agp.o os-interface.o os-registry.o nv-i2c.o nvidia.mod.o
   rm -f -f build-in.o nv-linux.o *.d .*.{cmd,flags}
   rm -f -f nvidia.{o,ko,mod.{o,c}} nv_compiler.h *~
   rm -f -f stprof stprof.o symtab.h
   rm -f -rf .tmp_versions
-> Building kernel module:
   executing: 'cd ./usr/src/nv; make module SYSSRC=/lib/modules/2.6.15-26-386/b
   uild SYSOUT=/lib/modules/2.6.15-26-386/build'...
   
   NVIDIA: calling KBUILD...
   make CC=cc  KBUILD_VERBOSE=1 -C /lib/modules/2.6.15-26-386/build SUBDIRS=/tm
   p/selfgz8395/NVIDIA-Linux-x86-1.0-8762-pkg1/usr/src/nv modules
   mkdir -p /tmp/selfgz8395/NVIDIA-Linux-x86-1.0-8762-pkg1/usr/src/nv/.tmp_vers
   ions
   make -f scripts/Makefile.build obj=/tmp/selfgz8395/NVIDIA-Linux-x86-1.0-8762
   -pkg1/usr/src/nv
   echo \#define NV_COMPILER \"`cc -v 2>&1 | tail -n 1`\" > /tmp/selfgz8395/NVI
   DIA-Linux-x86-1.0-8762-pkg1/usr/src/nv/nv_compiler.h
     cc -Wp,-MD,/tmp/selfgz8395/NVIDIA-Linux-x86-1.0-8762-pkg1/usr/src/nv/.nv.o
   .d  -nostdinc -isystem /usr/lib/gcc/i486-linux-gnu/4.0.3/include -D__KERNEL_
   _ -Iinclude  -include include/linux/autoconf.h -Wall -Wundef -Wstrict-protot
   ypes -Wno-trigraphs -fno-strict-aliasing -fno-common -ffreestanding -O2     
   -fomit-frame-pointer -pipe -msoft-float -mpreferred-stack-boundary=2 -fno-un
   it-at-a-time -march=i486 -Iinclude/asm-i386/mach-default -Wdeclaration-after
   -statement -Wno-pointer-sign -I/tmp/selfgz8395/NVIDIA-Linux-x86-1.0-8762-pkg
   1/usr/src/nv -Wall -Wi
   mplicit -Wreturn-type -Wswitch -Wformat -Wchar-subscripts -Wparentheses -Wpo
   inter-arith  -Wno-multichar  -Werror -O -fno-common -MD   -Wsign-compare -Wn
   o-cast-qual -Wno-error -D_LOOSE_KERNEL_NAMES -D__KERNEL__ -DMODULE  -DNTRM -
   DNVRM -DDYNAMIC_SLI  -DNV_MAJOR_VERSION=1 -DNV_MINOR_VERSION=0 -DNV_PATCHLEV
   EL=8762  -UDEBUG -U_DEBUG -DNDEBUG -DNV_SIGNAL_STRUCT_RLIM -DNV_MULTIPLE_BRI
   DGE_AGPGART_PRESENT -DNV_PCI_GET_CLASS_PRESENT -DNV_SYSCTL_MAX_MAP_COUNT_PRE
   SENT -DNV_PM_MESSAGE_T_PRESENT -DNV_PCI_CHOOSE_STATE_PRESENT -DNV_VM_INSERT_
   PAGE_PRESENT -DNV_REMAP_PFN_RANGE_PRESENT -DNV_CHANGE_PAGE_ATTR_PRESENT -DNV
   _VMAP_4_PRESENT  -DMODULE -DKBUILD_BASENAME=nv -DKBUILD_MODNAME=nvidia -c -o
   /tmp/selfgz8395/NVIDIA-Linux-x86-1.0-8762-pkg1/usr/src/nv/.tmp_nv.o /tmp/sel
   fgz8395/NVIDIA-Linux-x86-1.0-8762-pkg1/usr/src/nv/nv.c
   In file included from include/linux/bitops.h:77,
                    from include/linux/kernel.h:15,
                    from /tmp/selfgz8395/NVIDIA-Linux-x86-1.0-8762-pkg1/usr/src
   /nv/nv-linux.h:50,
                    from /tmp/selfgz8395/NVIDIA-Linux-x86-1.0-8762-pkg1/usr/src
   /nv/nv.c:14:
   include/asm/bitops.h: In function ‘find_first_bit’:
   include/asm/bitops.h:326: warning: comparison between signed and unsigned
   In file included from include/linux/list.h:7,
                    from include/linux/wait.h:23,
                    from include/asm/semaphore.h:41,
                    from include/linux/sched.h:20,
                    from include/linux/module.h:10,
                    from /tmp/selfgz8395/NVIDIA-Linux-x86-1.0-8762-pkg1/usr/src
   /nv/nv-linux.h:51,
                    from /tmp/selfgz8395/NVIDIA-Linux-x86-1.0-8762-pkg1/usr/src
   /nv/nv.c:14:
   include/linux/prefetch.h: In function ‘prefetch_range’:
   include/linux/prefetch.h:62: warning: pointer of type ‘void *’ used in a
   rithmetic
   In file included from include/linux/dmapool.h:14,
                    from include/linux/pci.h:485,
                    from /tmp/selfgz8395/NVIDIA-Linux-x86-1.0-8762-pkg1/usr/src
   /nv/nv-linux.h:76,
                    from /tmp/selfgz8395/NVIDIA-Linux-x86-1.0-8762-pkg1/usr/src
   /nv/nv.c:14:
   include/asm/io.h: In function ‘check_signature’:
   include/asm/io.h:253: warning: wrong type argument to increment
     cc -Wp,-MD,/tmp/selfgz8395/NVIDIA-Linux-x86-1.0-8762-pkg1/usr/src/nv/.nv-v
   m.o.d  -nostdinc -isystem /usr/lib/gcc/i486-linux-gnu/4.0.3/include -D__KERN
   EL__ -Iinclude  -include include/linux/autoconf.h -Wall -Wundef -Wstrict-pro
   totypes -Wno-trigraphs -fno-strict-aliasing -fno-common -ffreestanding -O2  
     -fomit-frame-pointer -pipe -msoft-float -mpreferred-stack-boundary=2 -fno-
   unit-at-a-time -march=i486 -Iinclude/asm-i386/mach-default -Wdeclaration-aft
   er-statement -Wno-pointer-sign -I/tmp/selfgz8395/NVIDIA-Linux-x86-1.0-8762-p
   kg1/usr/src/nv -Wall -Wimplicit -Wreturn-type -Wswitch -Wformat -Wchar-subsc
   ripts -Wparentheses -Wpointer-arith  -Wno-multichar  -Werror -O -fno-common 
   -MD   -Wsign-compare -Wno-cast-qual -Wno-error -D_LOOSE_KERNEL_NAMES -D__KER
   NEL__ -DMODULE  -DNTRM -DNVRM -DDYNAMIC_SLI  -DNV_MAJOR_VERSION=1 -DNV_MINOR
   _VERSION=0 -DNV_PATCHLEVEL=8762  -UDEBU
   G -U_DEBUG -DNDEBUG -DNV_SIGNAL_STRUCT_RLIM -DNV_MULTIPLE_BRIDGE_AGPGART_PRE
   SENT -DNV_PCI_GET_CLASS_PRESENT -DNV_SYSCTL_MAX_MAP_COUNT_PRESENT -DNV_PM_ME
   SSAGE_T_PRESENT -DNV_PCI_CHOOSE_STATE_PRESENT -DNV_VM_INSERT_PAGE_PRESENT -D
   NV_REMAP_PFN_RANGE_PRESENT -DNV_CHANGE_PAGE_ATTR_PRESENT -DNV_VMAP_4_PRESENT
    -DMODULE -DKBUILD_BASENAME=nv_vm -DKBUILD_MODNAME=nvidia -c -o /tmp/selfgz8
   395/NVIDIA-Linux-x86-1.0-8762-pkg1/usr/src/nv/.tmp_nv-vm.o /tmp/selfgz8395/N
   VIDIA-Linux-x86-1.0-8762-pkg1/usr/src/nv/nv-vm.c
   In file included from include/linux/bitops.h:77,
                    from include/linux/kernel.h:15,
                    from /tmp/selfgz8395/NVIDIA-Linux-x86-1.0-8762-pkg1/usr/src
   /nv/nv-linux.h:50,
                    from /tmp/selfgz8395/NVIDIA-Linux-x86-1.0-8762-pkg1/usr/src
   /nv/nv-vm.c:14:
   include/asm/bitops.h: In function ‘find_first_bit’:
   include/asm/bitops.h:326: warning: comparison between signed and unsigned
   In file included from include/linux/list.h:7,
                    from include/linux/wait.h:23,
                    from include/asm/semaphore.h:41,
                    from include/linux/sched.h:20,
                    from include/linux/module.h:10,
                    from /tmp/selfgz8395/NVIDIA-Linux-x86-1.0-8762-pkg1/usr/src
   /nv/nv-linux.h:51,
                    from /tmp/selfgz8395/NVIDIA-Linux-x86-1.0-8762-pkg1/usr/src
   /nv/nv-vm.c:14:
   include/linux/prefetch.h: In function ‘prefetch_range’:
   include/linux/prefetch.h:62: warning: pointer of type ‘void *’ used in a
   rithmetic
   In file included from include/linux/dmapool.h:14,
                    from include/linux/pci.h:485,
                    from /tmp/selfgz8395/NVIDIA-Linux-x86-1.0-8762-pkg1/usr/src
   /nv/nv-linux.h:76,
                    from /tmp/selfgz8395/NVIDIA-Linux-x86-1.0-8762-pkg1/usr/src
   /nv/nv-vm.c:14:
   include/asm/io.h: In function ‘check_signature’:
   include/asm/io.h:253: warning: wrong type argument to increment
     cc -Wp,-MD,/tmp/selfgz8395/NVIDIA-Linux-x86-1.0-8762-pkg1/usr/src/nv/.os-a
   gp.o.d  -nostdinc -isystem /usr/lib/gcc/i486-linux-gnu/4.0.3/include -D__KER
   NEL__ -Iinclude  -include include/linux/autoconf.h -Wall -Wundef -Wstrict-pr
   ototypes -Wno-trigraphs -fno-strict-aliasing -fno-common -ffreestanding -O2 
      -fomit-frame-pointer -pipe -msoft-float -mpreferred-stack-boundary=2 -fno
   -unit-at-a-time -march=i486 -Iinclude/asm-i386/mach-default -Wdeclaration-af
   ter-statement -Wno-pointer-sign -I/tmp/selfgz8395/NVIDIA-Linux-x86-1.0-8762-
   pkg1/usr/src/nv -Wall -Wimplicit -Wreturn-type -Wswitch -Wformat -Wchar-subs
   cripts -Wparentheses -Wpointer-arith  -Wno-multichar  -Werror -O -fno-common
   -MD   -Wsign-compare -Wno-cast-qual -Wno-error -D_LOOSE_KERNEL_NAMES -D__KER
   NEL__ -DMODULE  -DNTRM -DNVRM -DDYNAMIC_SLI  -DNV_MAJOR_VERSION=1 -DNV_MINOR
   _VERSION=0 -DNV_PATCHLEVEL=8762  -UDEBUG -U_DEBUG -DNDEBUG -DNV_SIGNAL_STRUC
   T_RLIM -DNV_MULTIPLE_BRIDGE_AGPGART_PRESENT -DNV_PCI_GET_CLASS_PRESENT -DNV_
   SYSCTL_MAX_MAP_COUNT_PRESENT -DNV_PM_MESSAGE_T_PRESENT -DNV_PCI_CHOOSE_STATE
   _PRESENT -DNV_VM_INSERT_PAGE_PRESENT -DNV_REMAP_PFN_RANGE_PRESENT -DNV_CHANG
   E_PAGE_ATTR_PRESENT -DNV_VMAP_4_PRE
   SENT  -DMODULE -DKBUILD_BASENAME=os_agp -DKBUILD_MODNAME=nvidia -c -o /tmp/s
   elfgz8395/NVIDIA-Linux-x86-1.0-8762-pkg1/usr/src/nv/.tmp_os-agp.o /tmp/selfg
   z8395/NVIDIA-Linux-x86-1.0-8762-pkg1/usr/src/nv/os-agp.c
   In file included from include/linux/bitops.h:77,
                    from include/linux/kernel.h:15,
                    from /tmp/selfgz8395/NVIDIA-Linux-x86-1.0-8762-pkg1/usr/src
   /nv/nv-linux.h:50,
                    from /tmp/selfgz8395/NVIDIA-Linux-x86-1.0-8762-pkg1/usr/src
   /nv/os-agp.c:24:
   include/asm/bitops.h: In function ‘find_first_bit’:
   include/asm/bitops.h:326: warning: comparison between signed and unsigned
   In file included from include/linux/list.h:7,
                    from include/linux/wait.h:23,
                    from include/asm/semaphore.h:41,
                    from include/linux/sched.h:20,
                    from include/linux/module.h:10,
                    from /tmp/selfgz8395/NVIDIA-Linux-x86-1.0-8762-pkg1/usr/src
   /nv/nv-linux.h:51,
                    from /tmp/selfgz8395/NVIDIA-Linux-x86-1.0-8762-pkg1/usr/src
   /nv/os-agp.c:24:
   include/linux/prefetch.h: In function ‘prefetch_range’:
   include/linux/prefetch.h:62: warning: pointer of type ‘void *’ used in a
   rithmetic
   In file included from include/linux/dmapool.h:14,
                    from include/linux/pci.h:485,
                    from /tmp/selfgz8395/NVIDIA-Linux-x86-1.0-8762-pkg1/usr/src
   /nv/nv-linux.h:76,
                    from /tmp/selfgz8395/NVIDIA-Linux-x86-1.0-8762-pkg1/usr/src
   /nv/os-agp.c:24:
   include/asm/io.h: In function ‘check_signature’:
   include/asm/io.h:253: warning: wrong type argument to increment
     cc -Wp,-MD,/tmp/selfgz8395/NVIDIA-Linux-x86-1.0-8762-pkg1/usr/src/nv/.os-i
   nterface.o.d  -nostdinc -isystem /usr/lib/gcc/i486-linux-gnu/4.0.3/include -
   D__KERNEL__ -Iinclude  -include include/linux/autoconf.h -Wall -Wundef -Wstr
   ict-prototypes -Wno-trigraphs -fno-strict-aliasing -fno-common -ffreestandin
   g -O2     -fomit-frame-pointer -pipe -msoft-float -mpreferred-stack-boundary
   =2 -fno-unit-at-a-time -march=i486 -Iinclude/asm-i386/mach-default 
   -Wdeclaration-after-statement -Wno-pointer-sign -I/tmp/selfgz8395/NVIDIA-Lin
   ux-x86-1.0-8762-pkg1/usr/src/nv -Wall -Wimplicit -Wreturn-type -Wswitch -Wfo
   rmat -Wchar-subscripts -Wparentheses -Wpointer-arith  -Wno-multichar  -Werro
   r -O -fno-common -MD   -Wsign-compare -Wno-cast-qual -Wno-error -D_LOOSE_KER
   NEL_NAMES -D__KERNEL__ -DMODULE  -DNTRM -DNVRM -DDYNAMIC_SLI  -DNV_MAJOR_VER
   SION=1 -DNV_MINOR_VERSION=0 -DNV_PATCHLEVEL=8762  -UDEBUG -U_DEBUG -DNDEBUG 
   -DNV_SIGNAL_STRUCT_RLIM -DNV_MULTIPLE_BRIDGE_AGPGART_PRESENT -DNV_PCI_GET_CL
   ASS_PRESENT -DNV_SYSCTL_MAX_MAP_COUNT_PRESENT -DNV_PM_MESSAGE_T_PRESENT -DNV
   _PCI_CHOOSE_STATE_PRESENT -DNV_VM_INSERT_PAGE_PRESENT -DNV_REMAP_PFN_RANGE_P
   RESENT -DNV_CHANGE_PAGE_ATTR_PRESENT -DNV_VMAP_4_PRESENT  -DMODULE -DKBUILD_
   BASENAME=os_interface -DKBUILD_MODNAME=nvidia -c -o /tmp/selfgz8395/NVIDIA-L
   inux-x86-1.0-8762-pkg1/usr/src/nv/.tmp_os-interface.o /tmp/selfgz8395/NVIDIA
   -Linux-x86-1.0-8762-pkg1/usr/src/nv/os-interface.c
   In file included from include/linux/bitops.h:77,
                    from include/linux/kernel.h:15,
                    from /tmp/selfgz8395/NVIDIA-Linux-x86-1.0-8762-pkg1/usr/src
   /nv/nv-linux.h:50,
                    from /tmp/selfgz8395/NVIDIA-Linux-x86-1.0-8762-pkg1/usr/src
   /nv/os-interface.c:26:
   include/asm/bitops.h: In function ‘find_first_bit’:
   include/asm/bitops.h:326: warning: comparison between signed and unsigned
   In file included from include/linux/list.h:7,
                    from include/linux/wait.h:23,
                    from include/asm/semaphore.h:41,
                    from include/linux/sched.h:20,
                    from include/linux/module.h:10,
                    from /tmp/selfgz8395/NVIDIA-Linux-x86-1.0-8762-pkg1/usr/src
   /nv/nv-linux.h:51,
                    from /tmp/selfgz8395/NVIDIA-Linux-x86-1.0-8762-pkg1/usr/src
   /nv/os-interface.c:26:
   include/linux/prefetch.h: In function ‘prefetch_range’:
   include/linux/prefetch.h:62: warning: pointer of type ‘void *’ used in a
   rithmetic
   In file included from include/linux/dmapool.h:14,
                    from include/linux/pci.h:485,
                    from /tmp/selfgz8395/NVIDIA-Linux-x86-1.0-8762-pkg1/usr/src
   /nv/nv-linux.h:76,
                    from /tmp/selfgz8395/NVIDIA-Linux-x86-1.0-8762-pkg1/usr/src
   /nv/os-interface.c:26:
   include/asm/io.h: In function ‘check_signature’:
   include/asm/io.h:253: warning: wrong type argument to increment
     cc -Wp,-MD,/tmp/selfgz8395/NVIDIA-Linux-x86-1.0-8762-pkg1/usr/src/nv/.os-r
   egistry.o.d  -nostdinc -isystem /usr/lib/gcc/i486-linux-gnu/4.0.3/include -D
   __KERNEL__ -Iinclude  -include include/linux/autoconf.h -Wall -Wundef -Wstri
   ct-prototypes -Wno-trigraphs -fno-strict-aliasing -fno-common -ffreestanding
   -O2     -fomit-frame-pointer -pipe -msoft-float -mpreferred-stack-boundary=2
   -fno-unit-at-a-time -march=i486 -Iinclude/asm-i386/mach-default -Wdeclaratio
   n-after-statement -Wno-pointer-sign -I/tmp/selfgz8395/NVIDIA-Linux-x86-1.0-8
   762-pkg1/usr/src/nv -Wall -Wimplicit -Wreturn-type -Wswitch -Wformat -Wchar-
   subscripts -Wparentheses -Wpointer-arith  -Wno-multichar  -Werror -O -fno-co
   mmon -MD   -W
   sign-compare -Wno-cast-qual -Wno-error -D_LOOSE_KERNEL_NAMES -D__KERNEL__ -D
   MODULE  -DNTRM -DNVRM -DDYNAMIC_SLI  -DNV_MAJOR_VERSION=1 -DNV_MINOR_VERSION
   =0 -DNV_PATCHLEVEL=8762  -UDEBUG -U_DEBUG -DNDEBUG -DNV_SIGNAL_STRUCT_RLIM -
   DNV_MULTIPLE_BRIDGE_AGPGART_PRESENT -DNV_PCI_GET_CLASS_PRESENT -DNV_SYSCTL_M
   AX_MAP_COUNT_PRESENT -DNV_PM_MESSAGE_T_PRESENT -DNV_PCI_CHOOSE_STATE_PRESENT
   -DNV_VM_INSERT_PAGE_PRESENT -DNV_REMAP_PFN_RANGE_PRESENT -DNV_CHANGE_PAGE_AT
   TR_PRESENT -DNV_VMAP_4_PRESENT  -DMODULE -DKBUILD_BASENAME=os_registry -DKBU
   ILD_MODNAME=nvidia -c -o /tmp/selfgz8395/NVIDIA-Linux-x86-1.0-8762-pkg1/usr/
   src/nv/.tmp_os-registry.o /tmp/selfgz8395/NVIDIA-Linux-x86-1.0-8762-pkg1/usr
   /src/nv/os-registry.c
   In file included from include/linux/bitops.h:77,
                    from include/linux/kernel.h:15,
                    from /tmp/selfgz8395/NVIDIA-Linux-x86-1.0-8762-pkg1/usr/src
   /nv/nv-linux.h:50,
                    from /tmp/selfgz8395/NVIDIA-Linux-x86-1.0-8762-pkg1/usr/src
   /nv/os-registry.c:14:
   include/asm/bitops.h: In function ‘find_first_bit’:
   include/asm/bitops.h:326: warning: comparison between signed and unsigned
   In file included from include/linux/list.h:7,
                    from include/linux/wait.h:23,
                    from include/asm/semaphore.h:41,
                    from include/linux/sched.h:20,
                    from include/linux/module.h:10,
                    from /tmp/selfgz8395/NVIDIA-Linux-x86-1.0-8762-pkg1/usr/src
   /nv/nv-linux.h:51,
                    from /tmp/selfgz8395/NVIDIA-Linux-x86-1.0-8762-pkg1/usr/src
   /nv/os-registry.c:14:
   include/linux/prefetch.h: In function ‘prefetch_range’:
   include/linux/prefetch.h:62: warning: pointer of type ‘void *’ used in a
   rithmetic
   In file included from include/linux/dmapool.h:14,
                    from include/linux/pci.h:485,
                    from /tmp/selfgz8395/NVIDIA-Linux-x86-1.0-8762-pkg1/usr/src
   /nv/nv-linux.h:76,
                    from /tmp/selfgz8395/NVIDIA-Linux-x86-1.0-8762-pkg1/usr/src
   /nv/os-registry.c:14:
   include/asm/io.h: In function ‘check_signature’:
   include/asm/io.h:253: warning: wrong type argument to increment
     cc -Wp,-MD,/tmp/selfgz8395/NVIDIA-Linux-x86-1.0-8762-pkg1/usr/src/nv/.nv-i
   2c.o.d  -nostdinc -isystem /usr/lib/gcc/i486-linux-gnu/4.0.3/include -D__KER
   NEL__ -Iinclude  -include include/linux/autoconf.h -Wall -Wundef -Wstrict-pr
   ototypes -Wno-trigraphs -fno-strict-aliasing -fno-common -ffreestanding -O2 
      -fomit-frame-pointer -pipe -msoft-float -mpreferred-stack-boundary=2 -fno
   -unit-at-a-time -march=i486 -Iinclude/asm-i386/mach-default -Wdeclaration-af
   ter-statement -Wno-pointer-sign -I/tmp/selfgz8395/NVIDIA-Linux-x86-1.0-8762-
   pkg1/usr/src/nv -Wall -Wimplicit -Wreturn-type -Wswitch -Wformat -Wchar-subs
   cripts -Wparentheses -Wpointer-arith  -Wno-multichar  -Werror -O -fno-common
   -MD   -Wsign-compare -Wno-cast-qual -Wno-error -D_LOOSE_KERNEL_NAMES -D__KER
   NEL__ -DMODULE  -DNTRM -DNVRM -DDYNAMIC_SLI  -DNV_MAJOR_VERSION=1 -DNV_MINOR
   _VERSION=0 -DNV_PATCHLEVEL=8762  -UDEBUG -U_DEBUG -DNDEBUG -DNV_SIGNAL_STRUC
   T_RLIM -DNV_MULTIPLE_BRIDGE_AGPGART_PRESENT 
   -DNV_PCI_GET_CLASS_PRESENT -DNV_SYSCTL_MAX_MAP_COUNT_PRESENT -DNV_PM_MESSAGE
   _T_PRESENT -DNV_PCI_CHOOSE_STATE_PRESENT -DNV_VM_INSERT_PAGE_PRESENT -DNV_RE
   MAP_PFN_RANGE_PRESENT -DNV_CHANGE_PAGE_ATTR_PRESENT -DNV_VMAP_4_PRESENT  -DM
   ODULE -DKBUILD_BASENAME=nv_i2c -DKBUILD_MODNAME=nvidia -c -o /tmp/selfgz8395
   /NVIDIA-Linux-x86-1.0-8762-pkg1/usr/src/nv/.tmp_nv-i2c.o /tmp/selfgz8395/NVI
   DIA-Linux-x86-1.0-8762-pkg1/usr/src/nv/nv-i2c.c
   In file included from include/linux/bitops.h:77,
                    from include/linux/kernel.h:15,
                    from /tmp/selfgz8395/NVIDIA-Linux-x86-1.0-8762-pkg1/usr/src
   /nv/nv-linux.h:50,
                    from /tmp/selfgz8395/NVIDIA-Linux-x86-1.0-8762-pkg1/usr/src
   /nv/nv-i2c.c:8:
   include/asm/bitops.h: In function ‘find_first_bit’:
   include/asm/bitops.h:326: warning: comparison between signed and unsigned
   In file included from include/linux/list.h:7,
                    from include/linux/wait.h:23,
                    from include/asm/semaphore.h:41,
                    from include/linux/sched.h:20,
                    from include/linux/module.h:10,
                    from /tmp/selfgz8395/NVIDIA-Linux-x86-1.0-8762-pkg1/usr/src
   /nv/nv-linux.h:51,
                    from /tmp/selfgz8395/NVIDIA-Linux-x86-1.0-8762-pkg1/usr/src
   /nv/nv-i2c.c:8:
   include/linux/prefetch.h: In function ‘prefetch_range’:
   include/linux/prefetch.h:62: warning: pointer of type ‘void *’ used in a
   rithmetic
   In file included from include/linux/dmapool.h:14,
                    from include/linux/pci.h:485,
                    from /tmp/selfgz8395/NVIDIA-Linux-x86-1.0-8762-pkg1/usr/src
   /nv/nv-linux.h:76,
                    from /tmp/selfgz8395/NVIDIA-Linux-x86-1.0-8762-pkg1/usr/src
   /nv/nv-i2c.c:8:
   include/asm/io.h: In function ‘check_signature’:
   include/asm/io.h:253: warning: wrong type argument to increment
     ld -m elf_i386 -m elf_i386  -r -o /tmp/selfgz8395/NVIDIA-Linux-x86-1.0-876
   2-pkg1/usr/src/nv/nvidia.o /tmp/selfgz8395/NVIDIA-Linux-x86-1.0-8762-pkg1/us
   r/src/nv/nv-kernel.o /tmp/selfgz8395/NVIDIA-Linux-x86-1.0-8762-pkg1/usr/src/
   nv/nv.o /tmp/selfgz8395/NVIDIA-Linux-x86-1.0-8762-pkg1/usr/src/nv/nv-vm.o /t
   mp/selfgz8395/NVIDIA-Linux-x86-1.0-8762-pkg1/usr/src/nv/os-agp.o /tmp/selfgz
   8395/NVIDIA-Linux-x86-1.0-8762-pkg1/usr/src/nv/os-interface.o /tmp/selfgz839
   5/NVIDIA-Linux-x86-1.0-8762-pkg1/usr/src/nv/os-registry.o /tmp/selfgz8395/NV
   IDIA-Linux-x86-1.0-8762-pkg1/usr/src/nv/nv-i2c.o
     Building modules, stage 2.
   make -rR -f /usr/src/linux-headers-2.6.15-26-386/scripts/Makefile.modpost
     scripts/mod/modpost -m -a -i /usr/src/linux-headers-2.6.15-26-386/Module.s
   ymvers /tmp/selfgz8395/NVIDIA-Linux-x86-1.0-8762-pkg1/usr/src/nv/nvidia.o
   Warning: could not find /tmp/selfgz8395/NVIDIA-Linux-x86-1.0-8762-pkg1/usr/s
   rc/nv/.nv-kernel.o.cmd for /tmp/selfgz8395/NVIDIA-Linux-x86-1.0-8762-pkg1/us
   r/src/nv/nv-kernel.o
     cc -Wp,-MD,/tmp/selfgz8395/NVIDIA-Linux-x86-1.0-8762-pkg1/usr/src/nv/.nvid
   ia.mod.o.d  -nostdinc -isystem /usr/lib/gcc/i486-linux-gnu/4.0.3/include -D_
   _KERNEL__ -Iinclude  -include include/linux/autoconf.h -Wall -Wundef -Wstric
   t-prototypes -Wno-trigraphs -fno-strict-aliasing -fno-common -ffreestanding 
   -O2     -fomit-frame-pointer -pipe -msoft-float -mpreferred-stack-boundary=2
   -fno-unit-at-a-time -march=i486 -Iinclude/asm-i386/mach-default -Wdeclaratio
   n-after-statement -Wno-pointer-sign    -DKBUILD_BASENAME=nvidia -DKBUILD_MOD
   NAME=nvidia -DMODULE -c -o /tmp/selfgz8395/NVIDIA-Linux-x86-1.0-8762-pkg1/us
   r/src/nv/nvidia.mod.o /tmp/selfgz8395/NVIDIA-Linux-x86-1.0-8762-pkg1/usr/src
   /nv/nvidia.mod.c
     ld -m elf_i386 -m elf_i386 -r -o /tmp/selfgz8395/NVIDIA-Linux-x86-1.0-8762
   -pkg1/usr/src/nv/nvidia.ko /tmp/selfgz8395/NVIDIA-Linux-x86-1.0-8762-pkg1/us
   r/src/nv/nvidia.o /tmp/selfgz8395/NVIDIA-Linux-x86-1.0-8762-pkg1/usr/src/nv/
   nvidia.mod.o
   NVIDIA: left KBUILD.
-> done.
-> Kernel module compilation complete.
-> Kernel messages:
   [17181528.728000] sde: Write Protect is off
   [17181528.728000] sde: Mode Sense: 00 06 00 00
   [17181528.728000] sde: assuming drive cache: write through
   [17181528.748000] SCSI device sde: 522304 512-byte hdwr sectors (267 MB)
   [17181528.756000] sde: Write Protect is off
   [17181528.756000] sde: Mode Sense: 00 06 00 00
   [17181528.756000] sde: assuming drive cache: write through
   [17181528.756000]  sde: sde1
   [17181528.768000] sd 6:0:0:0: Attached scsi removable disk sde
   [17181528.768000] sd 6:0:0:0: Attached scsi generic sg4 type 0
   [17181528.768000] usb-storage: device scan complete
   [17181529.008000] printk: 2 messages suppressed.
   [17181529.008000] Buffer I/O error on device sde1, logical block 65287
   [17181529.008000] Buffer I/O error on device sde1, logical block 65287
   [17181529.008000] Buffer I/O error on device sde1, logical block 65287
   [17181529.008000] Buffer I/O error on device sde1, logical block 65287
   [17181529.008000] Buffer I/O error on device sde1, logical block 65287
   [17181529.008000] Buffer I/O error on device sde1, logical block 65287
   [17181529.160000] Buffer I/O error on device sde1, logical block 65287
   [17181529.160000] Buffer I/O error on device sde1, logical block 65287
   [17181529.160000] Buffer I/O error on device sde1, logical block 65287
   [17181529.160000] Buffer I/O error on device sde1, logical block 65287
   [17181529.352000] FAT: utf8 is not a recommended IO charset for FAT
   filesystems, filesystem will be case sensitive!
   [17182657.484000] ACPI: PCI Interrupt 0000:01:00.0[A] -> GSI 16 (level, low)
   -> IRQ 169
   [17182657.484000] NVRM: loading NVIDIA Linux x86 Kernel Module  1.0-8762 
   Mon May 15 13:06:38 PDT 2006
-> Installing both new and classic TLS OpenGL libraries.
-> Parsing log file:
-> done.
-> Validating previous installation:
-> The previously installed file '/usr/lib/libGL.so.1.0.8762' has a different
   checksum (1452389177) than when it was installed (3141345874). 
   /usr/lib/libGL.so.1.0.8762 will not be uninstalled.
-> The previously installed file '/usr/lib/libGLcore.so.1.0.8762' has a
   different checksum (3602297916) than when it was installed (2315641700). 
   /usr/lib/libGLcore.so.1.0.8762 will not be uninstalled.
-> The previously installed file '/usr/lib/libnvidia-tls.so.1.0.8762' has a
   different checksum (1383823564) than when it was installed (3146656368). 
   /usr/lib/libnvidia-tls.so.1.0.8762 will not be uninstalled.
-> The previously installed file '/usr/lib/tls/libnvidia-tls.so.1.0.8762' has a
   different checksum (3232999027) than when it was installed (1637204000). 
   /usr/lib/tls/libnvidia-tls.so.1.0.8762 will not be uninstalled.
-> The previously installed file '/usr/lib/libnvidia-cfg.so.1.0.8762' has a
   different checksum (795450518) than when it was installed (1578942398). 
   /usr/lib/libnvidia-cfg.so.1.0.8762 will not be uninstalled.
-> The previously installed file '/usr/bin/nvidia-settings' has a different
   checksum (3425197484) than when it was installed (2763052694). 
   /usr/bin/nvidia-settings will not be uninstalled.
-> The previously installed file '/usr/bin/nvidia-xconfig' has a different
   checksum (3228404281) than when it was installed (936573735). 
   /usr/bin/nvidia-xconfig will not be uninstalled.
-> done.
WARNING: Your driver installation has been altered since it was initially
         installed; this may happen, for example, if you have since installed
         the NVIDIA driver through a mechanism other than the nvidia-installer
         (such as rpm or with the NVIDIA tarballs).  The nvidia-installer will
         attempt to uninstall as best it can.  Please see the file
         '/var/log/nvidia-installer.log' for details.
-> Uninstalling NVIDIA Accelerated Graphics Driver for Linux-x86 (1.0-8762):
-> done.
-> Uninstallation of existing driver: NVIDIA Accelerated Graphics Driver for
   Linux-x86 (1.0-8762) is complete.
-> Installing 'NVIDIA Accelerated Graphics Driver for Linux-x86' (1.0-8762):
   executing: '/sbin/ldconfig'...
   executing: '/sbin/depmod -aq'...
-> done.
-> Driver file installation is complete.
-> Running post-install sanity check:
-> done.
-> Post-install sanity check passed.
-> Shared memory test passed.
-> Running runtime sanity check:
-> done.
-> Runtime sanity check passed.
-> Would you like to run the nvidia-xconfig utility to automatically update you
   r X configuration file so that the NVIDIA X driver will be used when you res
   tart X?  Any pre-existing X configuration file will be backed up. (Answer: Y
   es)
-> Your X configuration file has been successfully updated.  Installation of
   the NVIDIA Accelerated Graphics Driver for Linux-x86 (version: 1.0-8762) is
   now complete.